increase KLauncher timeout as a possible fix/workaround for #983110

* Sat Dec 07 2013 Kevin Kofler <Kevin@tigcc.ticalc.org> - 6:4.11.3-6
- increase KLauncher timeout as a possible fix/workaround for #983110
This commit is contained in:
Kevin Kofler 2013-12-07 03:42:15 +01:00
parent 487dc84f06
commit e3d77729c8
2 changed files with 19 additions and 1 deletions

View File

@ -0,0 +1,12 @@
diff -ur kdelibs-4.11.3/kinit/klauncher.cpp kdelibs-4.11.3-klauncher-timeout/kinit/klauncher.cpp
--- kdelibs-4.11.3/kinit/klauncher.cpp 2013-11-01 16:45:56.000000000 +0100
+++ kdelibs-4.11.3-klauncher-timeout/kinit/klauncher.cpp 2013-12-07 03:36:42.000000000 +0100
@@ -314,7 +314,7 @@
// Same thing if kdeinit dies without warning.
fd_set in;
- timeval tm = { 30, 0 }; // 30 seconds timeout, so we're not stuck in case kdeinit dies on us
+ timeval tm = { 60, 0 }; // 60 seconds timeout, so we're not stuck in case kdeinit dies on us
FD_ZERO ( &in );
FD_SET( sock, &in );
select( sock + 1, &in, 0, 0, &tm );

View File

@ -42,7 +42,7 @@
Summary: KDE Libraries
Version: 4.11.3
Release: 5%{?dist}
Release: 6%{?dist}
Name: kdelibs
Epoch: 6
@ -162,6 +162,9 @@ Patch61: kdelibs-4.9.3-dot.patch
# workaround for bz#969524 on arm
Patch62: kdelibs-4.11.3-arm.patch
# increase KLauncher timeout as a possible fix/workaround for #983110
Patch63: kdelibs-4.11.3-klauncher-timeout.patch
## upstream
# revert these commits for
@ -626,6 +629,9 @@ gtk-update-icon-cache %{_kde4_iconsdir}/hicolor &> /dev/null || :
%changelog
* Sat Dec 07 2013 Kevin Kofler <Kevin@tigcc.ticalc.org> - 6:4.11.3-6
- increase KLauncher timeout as a possible fix/workaround for #983110
* Fri Dec 06 2013 Rex Dieter <rdieter@fedoraproject.org> - 6:4.11.3-5
- respin autostart debuging patch
- %%check: support regression tests (default off)